---
name: Feature request
about: Suggest an idea for igraph
title: ''
labels: ''
assignees: ''

---

<!-- For requests to be considered, this form must be filled out in full, and
     use cases for the feature explained in detail, ideally with references. -->

**What is the feature or improvement you would like to see?**
A concise but mathematically precise description of the requested feature.

**Use cases for the feature**
Explain when and for what purpose the feature would be useful.

**References**
List any relevant references (papers or books describing relevant algorithms).
